package fr.mael.jiwigo.dao;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.jdom.Document;
import org.jdom.Element;

import fr.mael.jiwigo.Main;
import fr.mael.jiwigo.om.Category;
import fr.mael.jiwigo.transverse.enumeration.MethodsEnum;
import fr.mael.jiwigo.transverse.util.Outil;

/**
   Copyright (c) 2010, Mael
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of jiwigo nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
   DISCLAIMED. IN NO EVENT SHALL Mael BE LIABLE FOR ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   
 * Dao des catégories
 * @author mael
 *
 */
public class CategoryDao {
    /**
     * Logger
     */
    public static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Main.class);
    /**
     * Instance, afin d'utiliser un singleton
     */
    private static CategoryDao instance;

    /**
     * Constructeur privé, afin que seule l'instance soit accessible
     */
    private CategoryDao() {

    }

    /**
     * @return l'instance
     */
    public static CategoryDao getInstance() {
	if (instance == null) {
	    instance = new CategoryDao();
	}
	return instance;
    }

    /**
     * Lister les catégorie
     * @param rafraichir permet de dire si on utilise les catégories présentes dans le cache ou pas
     * @param recursive listing récursif des catégories
     * @return la liste des catégories
     * @throws IOException 
     */
    public List<Category> lister(boolean recursive) throws IOException {
	Document doc = Main.sessionManager.executerReturnDocument(MethodsEnum.LISTER_CATEGORIES.getLabel(),
		"recursive", String.valueOf(recursive));
	Element element = doc.getRootElement().getChild("categories");
	List<Element> listElement = (List<Element>) element.getChildren("category");
	ArrayList<Category> categories = new ArrayList<Category>();
	for (Element cat : listElement) {
	    Category myCat = new Category(cat);
	    categories.add(myCat);
	}
	return categories;
    }

    /**
     * Création d'une catégorie
     * @param category la catégorie à créer
     * @return true si la catégorie a bien été créée
     */
    public boolean creer(Category category) {
	try {
	    return Outil.checkOk(Main.sessionManager.executerReturnDocument(MethodsEnum.AJOUTER_CATEGORIE.getLabel(),
		    "name", category.getNom(), "parent", String.valueOf(category.getParentDirect())));
	} catch (IOException e) {
	    LOG.error(Outil.getStackTrace(e));
	}
	return false;
    }

}
