package fr.mael.jiwigo.ui.mainframe;

import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.JOptionPane;
import javax.swing.JPanel;

import fr.mael.jiwigo.om.Image;
import fr.mael.jiwigo.service.ImageService;
import fr.mael.jiwigo.transverse.util.Messages;
import fr.mael.jiwigo.transverse.util.Outil;
import fr.mael.jiwigo.transverse.util.filedrop.FileDrop;
import fr.mael.jiwigo.ui.ImagesManagement;

/**
   Copyright (c) 2010, Mael
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of jiwigo nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
   DISCLAIMED. IN NO EVENT SHALL Mael BE LIABLE FOR ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   
 * @author mael
 * Classe qui affiche toutes les miniatures d'une catégorie
 */
public class ThumbnailCategoryPanel extends JPanel {
    /**
     * Logger
     */
    public static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
	    .getLog(ThumbnailCategoryPanel.class);
    /**
     * L'id de la catégorie pour laquelle les miniatures doivent être affichées
     */
    private Integer categoryId;

    /**
     * Constructeur
     * @param categoryId l'id de la catégorie
     */
    public ThumbnailCategoryPanel(Integer categoryId) {
	this.categoryId = categoryId;
	this.setLayout(new FlowLayout());
	this.setPreferredSize(new Dimension(1000, 750));
	if (categoryId != null) {
	    rafraichir(categoryId, false);
	}
	//gestion du drag'n drop
	new FileDrop(System.out, this, new FileDrop.Listener() {
	    public void filesDropped(final java.io.File[] files) {
		for (int i = 0; i < files.length; i++) {
		    try {
			ImageService.getInstance().creer(files[i].getCanonicalPath(), getCategoryId());
			//on rafraichit
			rafraichir(getCategoryId(), true);
		    } catch (Exception e) {
			LOG.error(Outil.getStackTrace(e));
			//s'il y a une erreur lors de l'envoi
			JOptionPane.showMessageDialog(null, Messages.getMessage("sendingError") + files[i].getName(),
				Messages.getMessage("error"), JOptionPane.ERROR_MESSAGE);
		    }
		}

	    }
	});

    }

    /**
     * rafraichissement, afin d'afficher les nouvelles images
     * @param categoryId
     */
    public void rafraichir(Integer categoryId, boolean rafraichir) {
	this.categoryId = categoryId;
	this.removeAll();
	try {
	    ImagesManagement.LIST_IMAGE = ImageService.getInstance().listerParCategory(categoryId, rafraichir);
	    for (Image image : ImagesManagement.LIST_IMAGE) {
		try {
		    //		    MiniatureLabel label = new MiniatureLabel(image, this);
		    ThumbnailPanel panel = new ThumbnailPanel(image);
		    this.add(panel);
		} catch (Exception e) {

		}
	    }
	    this.repaint();
	    this.revalidate();
	} catch (Exception e) {
	    LOG.error(Outil.getStackTrace(e));
	    JOptionPane.showMessageDialog(null, Messages.getMessage("imagesListingError"),
		    Messages.getMessage("error"), JOptionPane.ERROR_MESSAGE);
	}
    }

    /**
     * @return the categoryId
     */
    public Integer getCategoryId() {
	return categoryId;
    }

    /**
     * @param categoryId the categoryId to set
     */
    public void setCategoryId(Integer categoryId) {
	this.categoryId = categoryId;
    }

}
